==> open-xchange-guard_1.0.0.orig.tar.bz2: open-xchange-guard-1.0.0/com.openexchange.guard/src/com/openexchange/guard/encr/PGPStringProcessor.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.encr;

import org.bouncycastle.openpgp.*;
import java.io.*;
import java.security.NoSuchProviderException;

public class PGPStringProcessor {

    public String EncryptString(PGPPublicKey key, String data) throws NoSuchProviderException, IOException, PGPException {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPUtils.encrypt(out, data.getBytes(), null, key, true, true);
        return (new String(out.toByteArray()));
    }

    public PGPResult DecryptString(PGPSecretKeyRing secretring, String passphrase, String data, PGPPublicKeyRing pgpRing) throws Exception {
        InputStream in = new ByteArrayInputStream(data.getBytes("UTF-8"));
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPResult result = PGPUtils.decryptFile(in, out, pgpRing, secretring, passphrase.toCharArray());
        return (result);
    }

    public PGPResult DecryptStream(PGPSecretKeyRing secretring, String passphrase, InputStream in, PGPPublicKeyRing pgpRing) throws Exception {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPResult result = PGPUtils.decryptFile(in, out, pgpRing, secretring, passphrase.toCharArray());
        return (result);
    }
}

==> open-xchange-guard_1.2.0.orig.tar.bz2: open-xchange-guard-1.2.0/com.openexchange.guard/src/com/openexchange/guard/encr/PGPStringProcessor.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.encr;

import org.bouncycastle.openpgp.*;
import java.io.*;
import java.security.NoSuchProviderException;

public class PGPStringProcessor {

    public String EncryptString(PGPPublicKey key, String data) throws NoSuchProviderException, IOException, PGPException {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPUtils.encrypt(out, data.getBytes("UTF-8"), null, key, true, true);
        return (new String(out.toByteArray()));
    }

    public PGPResult DecryptString(PGPSecretKeyRing secretring, String passphrase, String data, PGPPublicKeyRing pgpRing) throws Exception {
        InputStream in = new ByteArrayInputStream(data.getBytes("UTF-8"));
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPResult result = PGPUtils.decryptFile(in, out, pgpRing, secretring, passphrase.toCharArray());
        return (result);
    }

    public PGPResult DecryptStream(PGPSecretKeyRing secretring, String passphrase, InputStream in, PGPPublicKeyRing pgpRing) throws Exception {
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        PGPResult result = PGPUtils.decryptFile(in, out, pgpRing, secretring, passphrase.toCharArray());
        return (result);
    }
}
